﻿using AsReader251GMAUIDemo.Platforms.Droid;
using static AsReader251GMAUIDemo.Platforms.Droid.AsReader251GDefine;

namespace AsReader251GMAUIDemo;

public partial class MainPage : ContentPage
{
    private AsReader251GManager formManager;
    private AsReader251GDelegate asReader251GDelegate;
    private string appVersion;
    private string dllVereison;
    private string sdkVersion;
    private string firmwareVersion;
    private string rfModuleVersion;
    private string serialVersion;
    private string globalBandVersion;
    private int battery;

    public MainPage()
    {
        InitializeComponent();
        ConnectButton.Text = "Connect";
        MainActivityIndicator.IsRunning = false;
        formManager = AsReader251GManager.sharedInstance();
        asReader251GDelegate = AsReader251GDelegate.sharedInstance();
    }
    protected override void OnAppearing()
    {
        base.OnAppearing();
        if (formManager.isConnect == true)
        {
            reloadUI(true);
        }
        else
        {
            reloadUI(false);
        }
        asReader251GDelegate.OnStateChanged = (AsReader251G_ConnectionState state) =>
        {
            OnStateChanged(state);
        };
        asReader251GDelegate.OnKeyEvent = (AsReader251G_KeyType p1, AsReader251G_KeyState p2) =>
        {
            
        };
    }
    private void reloadUI(bool status)
    {
        if (status == true)
        {
            Task.Run(() =>
            {
                appVersion = formManager.GetAPPVersion();
                dllVereison = formManager.GetAsReader251GSDKDLL();
                sdkVersion = formManager.GetSDKVersion();
                firmwareVersion = formManager.GetFirmwareVersion();
                rfModuleVersion = formManager.GetRFModuleVersion();
                serialVersion = formManager.GetSerialNumber();
                globalBandVersion = formManager.GetGlobalBand();
                battery = formManager.GetBatteryStatus();
                MainThread.BeginInvokeOnMainThread(() =>
                {
                    ConnectButton.Text = "Disconnect";
                    APPVersionLabel.Text = appVersion;
                    DLLVersionLabel.Text = dllVereison;
                    SDKVersionLabel.Text = sdkVersion;
                    FirmwareVersionLabel.Text = firmwareVersion;
                    UHFLabel.Text = rfModuleVersion;
                    SNLabel.Text = serialVersion;
                    RegionLabel.Text = globalBandVersion;
                    CheckBattery(battery);
                    BarocdeScanLabel.TextColor = Colors.Black;
                    RFIDInventoryLabel.TextColor = Colors.Black;
                    LogoImage.Source = "asreader_log_on.png";
                    StopActivityIndicator();
                });
            });
        }
        else
        {
            MainThread.BeginInvokeOnMainThread(() =>
            {
                ConnectButton.Text = "Connect";
                APPVersionLabel.Text = "";
                DLLVersionLabel.Text = "";
                SDKVersionLabel.Text = "";
                FirmwareVersionLabel.Text = "";
                UHFLabel.Text = "";
                SNLabel.Text = "";
                RegionLabel.Text = "";
                BatteryImage.Source = "battery0.png";
                BarocdeScanLabel.TextColor = Colors.LightGray;
                RFIDInventoryLabel.TextColor = Colors.LightGray;
                LogoImage.Source = "asreader_log_off.png";
                StopActivityIndicator();
            });
        }
    }
    async void BarocdeScanClicked(object sender, EventArgs e)
    {
        if (formManager.isConnect)
        {
            await Navigation.PushAsync(new BarcodeScanPage());
        }
    }
    async void RFIDInventoryClicked(object sender, EventArgs e)
    {
        if (formManager.isConnect)
        {
            await Navigation.PushAsync(new RFIDInventoryPage());
        }
    }
    public void ConnectButton_Clicked(object sender, EventArgs e)
    {
        if (!formManager.isConnect)
        {
            StartActivityIndicator();
            formManager.ConnectDevice();
        }
        else
        {
            StartActivityIndicator();
            formManager.DisconnectDevice();
        }

    }
    private void OnStateChanged(AsReader251G_ConnectionState state)
    {
        if (state == AsReader251G_ConnectionState.Connected)
        {
            reloadUI(true);
        }
        else if (state == AsReader251G_ConnectionState.Connecting)
        {
            StartActivityIndicator();
        }
        else if (state == AsReader251G_ConnectionState.Disconnected)
        {
            reloadUI(false);
        }
        else if (state == AsReader251G_ConnectionState.SDKEventMessage)
        {
            MainThread.BeginInvokeOnMainThread(() =>
            {
                DisplayAlert("Alert", formManager.GetSDKMessage(), "OK");
            });
        }
    }
    private void CheckBattery(int battery)
    {
        switch (battery)
        {
            case 0:
                BatteryImage.Source = "battery0.png";
                break;
            case 1:
                BatteryImage.Source = "battery1.png";
                break;
            case 2:
                BatteryImage.Source = "battery2.png";
                break;
            case 3:
                BatteryImage.Source = "battery3.png";
                break;
            case 4:
                BatteryImage.Source = "battery4.png";
                break;
            default:
                return;
        }
    }
    public void StartActivityIndicator()
    {
        MainActivityIndicator.IsRunning = true;
        ConnectButton.IsEnabled = false;
    }
    public void StopActivityIndicator()
    {
        MainActivityIndicator.IsRunning = false;
        ConnectButton.IsEnabled = true;
    }
}



